@@ -18,9 +18,9 @@ import urllib.parse
 import http.client
 import httplib2
 import mimetypes
-import mimetools
 import re
 import inspect
+import email.generator
 
 import oauth2 as oauth
 
@@ -257,7 +257,7 @@ class Twython(object):
 
     @staticmethod
     def constructApiURL(base_url, params):
-        return base_url + "?" + "&"join(["%s=%s" % (key, urllib.parse.quote_plus(Twython.unicode2utf8(value))) for (key, value) in list(params.items())])
+        return base_url + "?" + "&".join(["%s=%s" % (key, urllib.parse.quote_plus(Twython.unicode2utf8(value))) for (key, value) in list(params.items())])
 	
     @staticmethod
     def shortenURL(url_to_shorten, shortener = "http://is.gd/api.php", query = "longurl"):
@@ -468,7 +468,7 @@ class Twython(object):
 
     @staticmethod
     def encode_multipart_formdata(fields, files):
-        BOUNDARY = mimetools.choose_boundary()
+        BOUNDARY = email.generator._make_boundary()
         CRLF = '\r\n'
         L = []
         for (key, value) in fields:
